@@ -7,6 +7,7 @@
 #include "complex.h"
 #include "fec.h"
 #include "fectable.h"
+#include "bch.h"
 #include "misc.h"
 
 /* --------------------------------------------------------------------- */
@@ -117,9 +118,11 @@ unsigned fecdecode(struct fecstate *f, unsigned data, unsigned *errors)
 		errors = 0;
 		break;
 	case 1:
-	case 2:
 		data = fec1511decode(data, errors);
 		break;
+	case 2:
+		data = decode_bch_codeword(data, errors);
+		break;
 	case 3:
 		data = walshdecode(data, errors);
 		break;
@@ -133,9 +136,11 @@ unsigned fecencode(struct fecstate *f, unsigned data)
 	case 0:
 		break;
 	case 1:
-	case 2:
 		data = fec1511encode(data);
 		break;
+	case 2:
+		data = encode_bch_codeword(data);
+		break;
 	case 3:
 		data = walshencode(data);
 		break;
