@@ -557,7 +557,7 @@ static struct soundmodem_state *init(const char *configfile)
 		sm->midipttfd = -1;
 	/* audio device */
 	if ((sm->audiofd = open(aname, O_RDWR)) == -1)
-		errprintf(SEV_FATAL, "cannot open audio device \"%s\"\n");
+		errprintf(SEV_FATAL, "cannot open audio device \"%s\"\n", aname);
 #ifdef HAVE_SYS_SOUNDCARD_H
 	if (ioctl(sm->audiofd, SNDCTL_DSP_GETCAPS, &apar) == -1)
 		errstr(SEV_FATAL, "ioctl: SNDCTL_DSP_GETCAPS");
@@ -601,14 +601,17 @@ static struct soundmodem_state *init(const char *configfile)
 		  (sm->drvmode & SNDDRVMODE_HALFDUPLEX) ? "half" : "full");
 	sm->samplerate  = apar;
 	sm->samplerateby100 = (apar+50) / 100;
+#if 1
 	/* we need to set the block size to something useful, i.e. approx 10ms */
 	apar = log2(sm->samplerateby100 + (sm->samplerateby100 >> 1));
 	if (!(sm->drvmode & SNDDRVMODE_CONVU8))
 		apar++;
-	apar |= 0x00030000; /* 0x7fff0000; */
+	apar |=  0x00030000; /* 0x7fff0000; */
 	errprintf(SEV_INFO, "audio driver fragment size %08x\n", apar);
 	if (ioctl(sm->audiofd, SNDCTL_DSP_SETFRAGMENT, &apar) == -1)
 		errstr(SEV_ERROR, "ioctl: SNDCTL_DSP_SETFRAGMENT");
+	errprintf(SEV_INFO, "audio driver fragment size %08x\n", apar);
+#endif
 	if (ioctl(sm->audiofd, SNDCTL_DSP_NONBLOCK, 0) == -1)
 		errstr(SEV_ERROR, "ioctl: SNDCTL_DSP_NONBLOCK");
 #endif /* HAVE_SYS_SOUNDCARD_H */
@@ -1084,8 +1087,8 @@ static void modem_run(struct soundmodem_state *sm)
  errprintf(SEV_INFO, "modem_run\n");
 #ifdef HAVE_SYS_SOUNDCARD_H
 	apar = PCM_ENABLE_INPUT;
-//	if (!(sm->drvmode & SNDDRVMODE_HALFDUPLEX))
-//		apar |= PCM_ENABLE_OUTPUT;
+	if (!(sm->drvmode & SNDDRVMODE_HALFDUPLEX))
+		apar |= PCM_ENABLE_OUTPUT;
 	if (ioctl(sm->audiofd, SNDCTL_DSP_SETTRIGGER, &apar) == -1)
 		errstr(SEV_FATAL, "ioctl: SNDCTL_DSP_SETTRIGGER");
 #endif /* HAVE_SYS_SOUNDCARD_H */
