@@ -2,7 +2,7 @@
 #define _NEWQPSKTX_H
 
 #include "complex.h"
-#include "nqconf.h"
+#include "modemconfig.h"
 
 /* --------------------------------------------------------------------- */
 
